# Supported Platforms

###### Regularly tested

- Arista vEOS
- Cisco ASA
- Cisco IOS
- Cisco IOS-XE
- Cisco IOS-XR
- Cisco NX-OS
- Cisco SG300
- HP ProCurve
- Juniper Junos
- Linux

###### Limited testing

- 6Wind
- Adtran OS
- Alcatel AOS6/AOS8
- Apresia Systems AEOS
- Broadcom ICOS
- Calix B6
- Centec Networks
- Cisco AireOS (Wireless LAN Controllers)
- CloudGenix ION
- Dell OS9 (Force10)
- Dell OS10
- Dell PowerConnect
- Ericsson IPOS
- Extreme ERS (Avaya)
- Extreme MLX/NetIron (Brocade/Foundry)
- Extreme TierraOS
- Extreme VDX (Brocade)
- Extreme VSP (Avaya)
- HPE Comware7
- Huawei
- Huawei OLT
- Huawei SmartAX
- IP Infusion OcNOS
- Juniper ScreenOS
- MikroTik RouterOS
- MikroTik SwitchOS
- NetApp cDOT
- Netgear ProSafe
- Nokia/Alcatel SR OS
- NVIDIA-Mellanox
- OneAccess
- Palo Alto PAN-OS
- Pluribus
- Ruckus ICX/FastIron
- Ruijie Networks
- Supermicro SMIS
- TPLink JetStream
- Ubiquiti EdgeSwitch
- Vyatta VyOS
- Yamaha
- ZTE ZXROS

###### Experimental

- A10
- Accedian
- Allied Telesis AlliedWare Plus
- Aruba
- Brocade Fabric OS
- C-DOT CROS
- Ciena SAOS
- Citrix Netscaler
- Cisco Telepresence
- Cisco Viptela
- Check Point GAiA
- Coriant
- Dell OS6
- Dell EMC Isilon
- Eltex
- Enterasys
- Endace
- Extreme EXOS
- Extreme Wing
- Extreme SLX (Brocade)
- F5 TMSH
- F5 Linux
- Fortinet
- MRV Communications OptiSwitch
- MRV LX
- Nokia/Alcatel SR-OS
- QuantaMesh
- Rad ETX
- Raisecom ROAP
- Sophos SFOS
- Ubiquiti Unifi Switch
- Versa Networks FlexVNF
- Watchguard Firebox
- Zyxel NOS
- 6WIND TurboRouter

###### Supported SSH device_type values

- a10
- accedian
- adtran_os
- alcatel_aos
- alcatel_sros
- allied_telesis_awplus
- apresia_aeos
- arista_eos
- aruba_os
- aruba_osswitch
- aruba_procurve
- avaya_ers
- avaya_vsp
- broadcom_icos
- brocade_fastiron
- brocade_fos
- brocade_netiron
- brocade_nos
- brocade_vdx
- brocade_vyos
- calix_b6
- cdot_cros
- centec_os
- checkpoint_gaia
- ciena_saos
- cisco_asa
- cisco_ftd
- cisco_ios
- cisco_nxos
- cisco_s300
- cisco_tp
- cisco_viptela
- cisco_wlc
- cisco_xe
- cisco_xr
- cloudgenix_ion
- coriant
- dell_dnos9
- dell_force10
- dell_isilon
- dell_os10
- dell_os6
- dell_os9
- dell_powerconnect
- dell_sonic
- dlink_ds
- eltex
- eltex_esr
- endace
- enterasys
- ericsson_ipos
- extreme
- extreme_ers
- extreme_exos
- extreme_netiron
- extreme_nos
- extreme_slx
- extreme_vdx
- extreme_vsp
- extreme_wing
- f5_linux
- f5_ltm
- f5_tmsh
- flexvnf
- fortinet
- generic
- generic_termserver
- hp_comware
- hp_procurve
- huawei
- huawei_olt
- huawei_smartax
- huawei_vrpv8
- ipinfusion_ocnos
- juniper
- juniper_junos
- juniper_screenos
- keymile
- keymile_nos
- linux
- mellanox
- mellanox_mlnxos
- mikrotik_routeros
- mikrotik_switchos
- mrv_lx
- mrv_optiswitch
- netapp_cdot
- netgear_prosafe
- netscaler
- nokia_sros
- oneaccess_oneos
- ovs_linux
- paloalto_panos
- pluribus
- quanta_mesh
- rad_etx
- raisecom_roap
- ruckus_fastiron
- ruijie_os
- sixwind_os
- sophos_sfos
- supermicro_smis
- tplink_jetstream
- ubiquiti_edge
- ubiquiti_edgerouter
- ubiquiti_edgeswitch
- ubiquiti_unifiswitch
- vyatta_vyos
- vyos
- watchguard_fireware
- yamaha
- zte_zxros
- zyxel_os
 
###### Supported Telnet device_type values
 
- adtran_os_telnet
- apresia_aeos_telnet
- arista_eos_telnet
- aruba_procurve_telnet
- brocade_fastiron_telnet
- brocade_netiron_telnet
- calix_b6_telnet
- centec_os_telnet
- ciena_saos_telnet
- cisco_ios_telnet
- cisco_s300_telnet
- cisco_xr_telnet
- dell_dnos6_telnet
- dell_powerconnect_telnet
- dlink_ds_telnet
- extreme_exos_telnet
- extreme_netiron_telnet
- extreme_telnet
- generic_telnet
- generic_termserver_telnet
- hp_comware_telnet
- hp_procurve_telnet
- huawei_olt_telnet
- huawei_telnet
- ipinfusion_ocnos_telnet
- juniper_junos_telnet
- nokia_sros_telnet
- oneaccess_oneos_telnet
- paloalto_panos_telnet
- rad_etx_telnet
- raisecom_telnet
- ruckus_fastiron_telnet
- ruijie_os_telnet
- supermicro_smis_telnet
- tplink_jetstream_telnet
- yamaha_telnet
- zte_zxros_telnet

###### Supported Secure Copy device_type values

- arista_eos
- ciena_saos
- cisco_asa
- cisco_ios
- cisco_nxos
- cisco_xe
- cisco_xr
- dell_os10
- juniper_junos
- linux
- nokia_sros
